@@ -1,5 +1,5 @@
 package FAIR::Accessor;
-$FAIR::Accessor::VERSION = '0.216';
+$FAIR::Accessor::VERSION = '0.230';
 
 
 
@@ -7,20 +7,30 @@ $FAIR::Accessor::VERSION = '0.216';
 
 
 
-#use lib "../";
 use base 'FAIR::AccessorBase';
-#
-#unless ($ENV{REQUEST_METHOD}){  # if running from command line
-#        $ENV{REQUEST_METHOD} = "GET";
-#        $ENV{'REQUEST_URI'} = "/this/thing";
-#        $ENV{'SERVER_NAME'} = "example.net";
-#	$ENV{'PATH_INFO'} = "/479-467-29X";
-#}
+
+#  for testing at the command-line...
+unless ($ENV{REQUEST_METHOD}){  # if running from command line
+
+    if ($ARGV[0]) {  # if there are any user-supplied arguments
+        $ENV{REQUEST_METHOD} = $ARGV[0];
+        $ENV{'SERVER_NAME'} = $ARGV[1] ;
+        $ENV{'REQUEST_URI'} = $ARGV[2];
+        $ENV{'PATH_INFO'} = $ARGV[3] ;
+    } else {
+        $ENV{REQUEST_METHOD} = "GET";
+        $ENV{'SERVER_NAME'} =  "example.net";
+        $ENV{'REQUEST_URI'} = "/this/thing";
+        $ENV{'PATH_INFO'} = "/1234567";
+    }
+}
+
 
 sub handle_requests {
 
     my $self = shift;
-    
+    my $base = $self->Configuration->basePATH();  # $base is a regular expression that separates the "path" from the "id" portion of the PATH_INFO environment variable
+    $base ||= "";
     # THIS ROUTINE WILL BE SHARED BY ALL SERVERS
     if ($ENV{REQUEST_METHOD} eq "HEAD") {
         $self->manageHEAD();
@@ -29,13 +39,22 @@ sub handle_requests {
         $self->manageHEAD();
         exit;
     }  elsif ($ENV{REQUEST_METHOD} eq "GET") {
-            if ($ENV{'PATH_INFO'}) {  # this will never happen with the minimal server
-                    $self->printResourceHeader();
-                    $self->manageResourceGET();
-            } else {
-                    $self->printContainerHeader();
-                    $self->manageContainerGET();
-            }
+        
+        unless ($ENV{'REQUEST_URI'} =~ /($base)\/*(.*)/){
+            print "Status: 500\n"; 
+            print "Content-type: text/plain\n\nThe configured basePATH argument does not match the request URI\n\n";
+            exit 0;
+        }
+        my ($path, $id) = ($1, $2);
+        print STDERR "PATH *$path* ID *$id*\n";
+        
+        if ($id) {  # this is a request like  /Allele/dip21  where the user is asking for a specific individual
+                $self->printResourceHeader();
+                $self->manageResourceGET('PATH' => $path, 'ID' => $id);
+        } else {  # this is a request like /Allele  or /Allele/  where the user is asking for the container
+                $self->printContainerHeader();
+                $self->manageContainerGET('PATH' => $path);
+        }
     } else {
         print "Status: 405 Method Not Allowed\n"; 
         print "Content-type: text/plain\n\nYou can only request HEAD, OPTIONS or GET from this LD Platform Server\n\n";
@@ -65,13 +84,13 @@ FAIR::Accessor - all this does is assign the HTTP call to the correct routine
 
 =head1 VERSION
 
-version 0.216
+version 0.230
 
 =head1 SYNOPSIS
 
 The following code is a complete implementation of a 'Hello, World!' FAIR Accessor
 
- #!/usr/bin/perl -w
+ C<#!/usr/bin/perl -w
 
  package HelloWorld_Accessor;  # this should be the same as your filename!
 
@@ -98,6 +117,7 @@ The following code is a complete implementation of a 'Hello, World!' FAIR Access
     localNamespaces => {hw => 'http://hello.world.org/some/items/',
                         hw2 => 'http://another.hello.world.org/some/predicates/'},  # add a few new namespaces to the list of known namespaces....
     localMetadataElements => [qw(hw:Greeting hw2:grusse) ],  # things that we use in addition to common metadata elements
+    # baseURI => 'some/regular/expression', # OPTIONAL regexp to match the RESTful PATH part of the URL, before the ID number
 
  };
 
@@ -113,22 +133,47 @@ The following code is a complete implementation of a 'Hello, World!' FAIR Access
 
 
 
- =head2 get_all_meta_URIs
+ =head2 MetaContainer
 
   Function: REQUIRED SUBROUTINE - returns the first-stage LD Platform list of contained URIs and the dataset metadata.
   Args    : $starting_at_record : this will be passed-in to tell you what record to start with (for paginated responses)
   $path : the webserver's PATH_INFO environment value (used to modify the behaviour of REST services)
   Returns : JSON encoded listref of 'meta URIs' representing individual records
   Note    :  meta URIs are generally URIs that point back to this same server; calling GET on a meta URI will
-            return an RDF description of the set of DCAT distributions for that record.\
-            this can be handled by the
+            return an RDF description of the set of DCAT distributions for that record.
+            The format of the JSON response is as follows:
+            
+            {"metadata:element1" : "some value",
+             "external:metadatatype":  "some other value",
+             "void:entities" : "3",
+             "ldp:contains" : ["http://myserver.org/ThisScript/record/479-467-29",
+                               "http://myserver.org/ThisScript/record/479-467-32",
+                               "http://myserver.org/ThisScript/record/479-467-434"
+                               ]
+            }
+            
+            Recommended metadata elements include dc:title, dcat:description,dcat:identifier,
+            dcat:keyword,dcat:landingPage,dcat:publisher,dcat:theme
+            
+            note #1:  Using dcat:theme requires you to create a SKOS concept scheme of the various ontology
+            terms that describe the data in your repository... this isn't hard, but it's not entirely trivial either...
+            
+            note #2:  if you return URLs in the ldp:contains, then you must also return the count of those URLs in void:entities
+
 
  =cut
 
- sub get_all_meta_URIs {
+ sub MetaContainer {
 
-    my ($starting_at_record, $path_info) = @_;
-    $path_info ||="";
+    my ($self, %ARGS) = @_;
+    my $PATH = $ARGS{'PATH'} || "";  # if there was a specific path sent after the script URL, it will be here
+    
+    # this is how you would manage "RESTful" references to different subsets of your data repository
+    if ($PATH =~ /DataSliceX/) {
+        # some behavior for Data Slice X
+    } elsif ($PATH =~ /DataSliceY/) {
+        # some behavior for Data Slice Y
+    }
     
     my %result =  (  # NOTE THAT ALL OF THESE ARE OPTIONAL!  (and there are more fields.... see DCAT...)
                     'dc:title' => "Hello World Accessor Server",
@@ -141,7 +186,7 @@ The following code is a complete implementation of a 'Hello, World!' FAIR Access
                     'dcat:temporal' => 'http://reference.data.gov.uk/id/quarter/2006-Q1',  # look at this!!  It doesn't have to be this complex, but it can be!
                     'dcat:theme'  => 'http://example.org/ConceptSchemes/HelloWorld.rdf',  # this is the URI to a SKOS Concept Scheme
                     );
-    my $BASE_URL = "http://" . $ENV{'SERVER_NAME'} . $ENV{'REQUEST_URI'} . $path_info;
+    my $BASE_URL = "http://" . $ENV{'SERVER_NAME'} . $ENV{'REQUEST_URI'} . $PATH;
 
    # you may chose to return no record IDs at all, if you only want to serve repository-level metadata     
     my @known_records = ($BASE_URL . "/hello",
@@ -156,35 +201,46 @@ The following code is a complete implementation of a 'Hello, World!' FAIR Access
  }
 
 
- =head2 get_distribution_URIs
+ =head2 Distributions
 
   Function: REQUIRED IF get_all_meta_URIs list of URIs point back to this script.
            returns the second-stage LD Platform metadata describing the DCAT distributions, formats, and URLs
            for a particular record
   Args    : $ID : the desired ID number, as determined by the Accessor.pm module
            $PATH_INFO : the webserver's PATH_INFO environment value (in case the $ID best-guess is wrong... then you're on your own!)
-  Returns : JSON encoded hashref of 'meta URIs' representing individual DCAT distributions and their formats (format is key)
-            The format for this response is:
+  Returns : JSON encoded hashref of 'meta URIs' representing individual DCAT distributions and their mime-type (mime-type is key)
+            The format for this response is (you are always allowed to use lists as values if you wish):
             
             {"metadata":
                 {"rdf:type": ["edam:data_0006","sio:SIO_000088"]
+                 "my:metadatathingy":  "some value",
+                 "external:metadatatype":  "some other value"
                 },
             "distributions":
-                {"application/rdf+xml":"http://myserver.org/ThisScript/record/479-467-29X.rdf",
-                 "text/html":"http://myserver.org/ThisScript/record/479-467-29X.html"
+                {"application/rdf+xml" : "http://myserver.org/ThisScript/record/479-467-29X.rdf",
+                 "text/html" : "http://myserver.org/ThisScript/record/479-467-29X.html"
                 }
             }
 
  =cut
 
 
- sub get_distribution_URIs {
-    my ($self, $ID, $PATH_INFO) = @_;
+ sub Distributions {
+    my ($self, %ARGS) = @_;
 
+    my $PATH = $ARGS{'PATH'};  
+    my $ID = $ARGS{'ID'};
+    
     my %response;
-
     my %formats;
     my %metadata;
+
+    # this is how you would manage "RESTful" references to different subsets of your data repository
+    if ($PATH =~ /DataSliceX/) {
+        # some behavior for Data Slice X
+    } elsif ($PATH =~ /DataSliceY/) {
+        # some behavior for Data Slice Y
+    }
     
     $formats{'text/html'} = 'http://myserver.org/ThisScript/helloworld.html';
     $formats{'application/rdf+xml'} = 'http://myserver.org/ThisScript/helloworld.rdf';
@@ -204,22 +260,47 @@ The following code is a complete implementation of a 'Hello, World!' FAIR Access
 
  }
 
+>
+
 =head1 DESCRIPTION
 
-FAIR Accessors are an implementation of the W3Cs Linked Data Platform.  FAIR Accessors follow a two-stage interaction model, where the first stage
-retrieves a series of URLs representing meta-records for every record in that repository (or whatever slice of the repository is being served).
-This is accomplished by the get_all_meta_URIs subroutine.  These URLs will generally point back at this same Accessor script (e.g. with the
-record number appended to the URL:  http://this.host/thisscript/12345).
+FAIR Accessors are an implementation of the W3Cs Linked Data Platform.
 
-This script then expresses metadata about that record, including the available DCAT distributions and their file formats.  This is
-accomplished by the get_distribution_URIs subroutine.
+FAIR Accessors follow a two-stage interaction, where the first stage
+retrieves metadata about the repository, and (optionally) a series of URLs representing
+'meta-records' for every record in that repository (or whatever slice of the repository
+is being served). This is accomplished by the B<MetaContainer> subroutine.  These URLs
+will generally point back at this same Accessor script (e.g. with the
+record number appended to the URL:  I<http://this.host/thisscript/12345>).
 
-The two subroutine names - get_all_meta_URIs  and  get_distribution_URIs - are not flexible, as they are called by the underlying libraries.
+The second stage involves retrieving metadata about individual recoreds.
+The metadata is up to you, but optimally it would include the available
+DCAT distributions and their file formats.  The second stage can be accomplished
+by this same Accessor script, using the Distributions subroutine.
+
+The two subroutine names - B<MetaContainer>  and  B<Distributions> - are not flexible, as they are
+called by-name, by the Accessor libraries.
+
+You B<MUST> create the B<MetaContainer> subroutine, at a minimum, and it should return some metadata.
+It does not have to return a list of known records (in which case it simply acts as a metadata
+descriptor of the repository in general, nothing more... which is fine!... and there will be no
+second stage interaction.  In this case, you do not need to provide a B<Distributions> subroutine.)
 
 =head1 NAME
 
     FAIR::Accessor - Module for creating Linked Data Platform Accessors for the FAIR Data project
 
+=head1 Command-line testing
+
+If you wish to test your Accessor server at the command line, you can run it with the following commandline arguments (in order):
+
+ Method (always GET, at the moment)
+ Domain
+ Request URI (i.e. the path to this script, including the script name)
+ PATH_INFO  (anything that should appear in the PATH_INFO variable of the webserver)
+
+  perl  myAccessorScript  GET  example.net  /this/myAccessorScript /1234567
+
 =head1 AUTHOR
 
 Mark Denis Wilkinson (markw [at] illuminae [dot] com)
