@@ -1,5 +1,5 @@
 package FAIR::AccessorConfig;
-$FAIR::AccessorConfig::VERSION = '0.216';
+$FAIR::AccessorConfig::VERSION = '0.230';
 
 
 # ABSTRACT: The key/value of the current configuration of the Accessor
@@ -27,6 +27,7 @@ my @CDE = qw(
     dcat:spatial
     dcat:temporal
     dcat:theme
+    dcat:license
     dc:title
     dcat:updateDate
     void:entities
@@ -70,8 +71,8 @@ has 'mechanizedLicenseInfo' => (
     is => 'rw',
 );
 
-has 'baseURI' => (
-    isa => 'Str',
+has 'basePATH' => (
+    isa => 'Str',  # string representing a regular expression to be applied against $ENV{PATH_INFO}
     is => 'rw',
 );
 
@@ -120,8 +121,8 @@ sub BUILD {
 	    print STDERR  "Failed to set namespace $abbreviation  ==  $namespace   Make sure your abbreviation has no capital letters (Perl library quirk!)";
 	}
     }
-    
-    $self->MetadataElements(\@CDE,$self->localMetadataElements() );  # concatinate local with common metadata elements
+    my @MetaDataElements = (@CDE, @{$self->localMetadataElements()});
+    $self->MetadataElements(\@MetaDataElements);  # concatinate local with common metadata elements
     
 }
 
@@ -139,7 +140,7 @@ FAIR::AccessorConfig - The key/value of the current configuration of the Accesso
 
 =head1 VERSION
 
-version 0.216
+version 0.230
 
 =head1 AUTHOR
 
